@@ -76,7 +76,8 @@ parseFileContentsWithExts exts = parseFileContentsWithMode (defaultParseMode { e
 parseFileContentsWithMode :: ParseMode -> String -> ParseResult Module
 parseFileContentsWithMode p@(ParseMode fn exts ign _ _) rawStr =
         let md = delit fn $ ppContents rawStr
-            allExts = impliesExts $ case (ign, readExtensions md) of
+            allExts = -- impliesExts $ 
+                            case (ign, readExtensions md) of
                                      (False,Just es) -> exts ++ es
                                      _               -> exts
          in parseWithMode (p { extensions = allExts }) md
