@@ -1285,8 +1285,15 @@ instance ExactP Exp where
          [a,b] -> do
             printString "<%"
             exactPC e
-            printString "%>"
+            printStringAt (pos b) "%>"
          _ -> errorEP "ExactP: Exp: XExpTag is given wrong number of srcInfoPoints"
+    XChildTag l es  ->
+        case srcInfoPoints l of
+         [a,b,c] -> do
+            printString "<%>"
+            mapM_ exactPC es
+            printStringAt (pos b) "</"
+            printStringAt (pos c) "%>"
 
     CorePragma l      str e         ->
         case srcInfoPoints l of
